/*****************************************************************************
 *
 * test_TMP102-Q1.c
 *
 * Copyright 2020 Inceptio Technology. All Rights Reserved.
 *
 *****************************************************************************/

#include "console.h"

#include "../TMP102_Q1/mcu_i2c.h"  /* for mcu_msWait() */
#include "../TMP102_Q1/TMP102.h"


extern const TMP102_Handle TMP102_0;
extern const TMP102_Handle TMP102_1;
extern const TMP102_Handle TMP102_2;
extern const TMP102_Handle TMP102_3;


extern uint32 g_tmp102_testing_second;
uint8  g_hasTmp102Configured;

//for test
int32_t configReg_Ch[4];
int32_t THighReg_Ch[4];
int32_t TLowReg_Ch[4];

/*
 * This function is to test TMP102-Q1 sensors
 * by read these sensors per  second.
 *
 *   To start the test in console  Shell>
 *      pwr T   --- set running_tmp102_test= 1
 *
 *  To end the test in console  Shell>
 *     pwr Q   --- reset running_tmp102_test= 0
 */
int TMP102_Q1_test(void)
{
	int32_t tmp1020Temp;
	int32_t tmp1020TempAsIntCelsius;
	int32_t tmp1020TempAsMilliCelsius;
//	float tmp1020TempAsFloatCelsius;

	int32_t tmp1021Temp;
	int32_t tmp1021TempAsIntCelsius;
	int32_t tmp1021TempAsMilliCelsius;
//	float tmp1021TempAsFloatCelsius;

	int32_t tmp1022Temp;
	int32_t tmp1022TempAsIntCelsius;
	int32_t tmp1022TempAsMilliCelsius;
//	float tmp1022TempAsFloatCelsius;

	int32_t tmp1023Temp;
	int32_t tmp1023TempAsIntCelsius;
	int32_t tmp1023TempAsMilliCelsius;
//	float tmp1023TempAsFloatCelsius;

    int32_t configReg=0;
    uint8_t alert = 0;

    // call config only once
    if (g_hasTmp102Configured == 0)
    {
        /* init sensors with values specified in ti_sensors_config.c */
    	Ifx_Console_print("TMP102-Q1 sensors is being initializing. WAIT........\r\n");
        TMP102_config(TMP102_0);
        TMP102_config(TMP102_1);
        TMP102_config(TMP102_2);
        TMP102_config(TMP102_3);
        Ifx_Console_print("........Done init TMP102-Q1 sensors.  Ready to monitor temperatures\r\n");
        g_hasTmp102Configured = 1;
    }

    /* Note: in continuous modes (CC), polling rate should
     *       not exceed sensor conversion rate
     */
    mcu_msWait(1000); /* delay 1 sec */

    Ifx_Console_print("-------Monitoring TMP102 Sensors Second%d ------------------------\r\n", g_tmp102_testing_second++);

    /* Read TMP102_0 temp */
    tmp1020Temp = TMP102_read(TMP102_0);
    tmp1020TempAsIntCelsius = TMP102_toIntCelsius(TMP102_0, tmp1020Temp);
    tmp1020TempAsMilliCelsius = TMP102_toMilliCelsius(TMP102_0, tmp1020Temp);
    THighReg_Ch[0] = TMP102_THighReg(TMP102_0);
    TLowReg_Ch[0] = TMP102_TLowReg(TMP102_0);
    configReg_Ch[0] = TMP102_readConfigReg(TMP102_0);
    alert = TMP102_TempHighAlert(TMP102_0, configReg);
//    tmp1020TempAsFloatCelsius = TMP102_toFloatCelsius(TMP102_0, tmp1020Temp);
    Ifx_Console_print("TempSenor0: TempAsIntCelsius=%d, TempAsMilliCelsius=%d, Alert=%d\r\n",
        tmp1020TempAsIntCelsius, tmp1020TempAsMilliCelsius, alert);
        //Aurix console_print not support float printout for now

    /* Read TMP102_1 temp */
    tmp1021Temp = TMP102_read(TMP102_1);
    tmp1021TempAsIntCelsius = TMP102_toIntCelsius(TMP102_1, tmp1021Temp);
    tmp1021TempAsMilliCelsius = TMP102_toMilliCelsius(TMP102_1, tmp1021Temp);
    THighReg_Ch[1] = TMP102_THighReg(TMP102_1);
    TLowReg_Ch[1] = TMP102_TLowReg(TMP102_1);
    configReg_Ch[1] = TMP102_readConfigReg(TMP102_1);
    alert = TMP102_TempHighAlert(TMP102_1, configReg);
//    tmp1021TempAsFloatCelsius = TMP102_toFloatCelsius(TMP102_1, tmp1021Temp);
    Ifx_Console_print("TempSenor1: TempAsIntCelsius=%d, TempAsMilliCelsius=%d, Alert=%d\r\n",
        tmp1021TempAsIntCelsius, tmp1021TempAsMilliCelsius, alert);

    /* Read TMP102_2 temp */
    tmp1022Temp = TMP102_read(TMP102_2);
    tmp1022TempAsIntCelsius = TMP102_toIntCelsius(TMP102_2, tmp1022Temp);
    tmp1022TempAsMilliCelsius = TMP102_toMilliCelsius(TMP102_2, tmp1022Temp);
    THighReg_Ch[2] = TMP102_THighReg(TMP102_2);
    TLowReg_Ch[2] = TMP102_TLowReg(TMP102_2);
    configReg_Ch[2] = TMP102_readConfigReg(TMP102_2);
    alert = TMP102_TempHighAlert(TMP102_2, configReg);

//    tmp1022TempAsFloatCelsius = TMP102_toFloatCelsius(TMP102_2, tmp1022Temp);
    Ifx_Console_print("TempSenor2: TempAsIntCelsius=%d, TempAsMilliCelsius=%d, Alert=%d\r\n",
        tmp1022TempAsIntCelsius, tmp1022TempAsMilliCelsius, alert);


    /* Read TMP102_3 temp */
    tmp1023Temp = TMP102_read(TMP102_3);
    tmp1023TempAsIntCelsius = TMP102_toIntCelsius(TMP102_3, tmp1023Temp);
    tmp1023TempAsMilliCelsius = TMP102_toMilliCelsius(TMP102_3, tmp1023Temp);
    THighReg_Ch[3] = TMP102_THighReg(TMP102_3);
    TLowReg_Ch[3] = TMP102_TLowReg(TMP102_3);
    configReg_Ch[3] = TMP102_readConfigReg(TMP102_3);
    alert = TMP102_TempHighAlert(TMP102_3, configReg);

//    tmp1023TempAsFloatCelsius = TMP102_toFloatCelsius(TMP102_3, tmp1023Temp);
    Ifx_Console_print("TempSenor3:TempAsIntCelsius=%d, TempAsMilliCelsius=%d, Alert=%d\r\n",
         tmp1023TempAsIntCelsius, tmp1023TempAsMilliCelsius, alert);

    return 0;
}
